@@ -15,6 +15,7 @@
 #define LEXBOR_STR_RES_MAP_HEX
 #define LEXBOR_STR_RES_MAP_NUM
 #include "lexbor/core/str_res.h"
+#include "lexbor/core/swar.h"
 
 #define LXB_HTML_TOKENIZER_RES_ENTITIES_SBST
 #include "lexbor/html/tokenizer/res.h"
@@ -226,6 +227,8 @@ lxb_html_tokenizer_state_data(lxb_html_tokenizer_t *tkz,
 {
     lxb_html_tokenizer_state_begin_set(tkz, data);
 
+    data = lexbor_swar_seek4(data, end, 0x3C, 0x26, 0x0D, 0x00);
+
     while (data != end) {
         switch (*data) {
             /* U+003C LESS-THAN SIGN (<) */
@@ -906,6 +909,8 @@ lxb_html_tokenizer_state_attribute_value_double_quoted(lxb_html_tokenizer_t *tkz
 
     lxb_html_tokenizer_state_begin_set(tkz, data);
 
+    data = lexbor_swar_seek4(data, end, 0x22, 0x26, 0x0D, 0x00);
+
     while (data != end) {
         switch (*data) {
             /* U+0022 QUOTATION MARK (") */
